@@ -23,8 +23,8 @@
 #include <QFile>
 #include <QDebug>
 
-FakeServer::FakeServer(QObject *parent) :
-    QThread(parent)
+FakeServer::FakeServer(QObject *parent)
+    : QThread(parent)
 {
     moveToThread(this);
 }
@@ -37,8 +37,8 @@ QByteArray FakeServer::greeting()
 QList<QByteArray> FakeServer::greetingAndEhlo(bool multiline)
 {
     return QList<QByteArray>() << greeting()
-           << "C: EHLO 127.0.0.1"
-           << QByteArray("S: 250") + (multiline ? '-' : ' ') + "Localhost ready to roll";
+                               << "C: EHLO 127.0.0.1"
+                               << QByteArray("S: 250") + (multiline ? '-' : ' ') + "Localhost ready to roll";
 }
 
 QList<QByteArray> FakeServer::bye()
@@ -46,7 +46,7 @@ QList<QByteArray> FakeServer::bye()
     return { "C: QUIT",
              "S: 221 So long, and thanks for all the fish",
              "X: "
-           };
+    };
 }
 
 FakeServer::~FakeServer()
@@ -64,8 +64,6 @@ void FakeServer::startAndWait()
 #else
     QMetaObject::invokeMethod(this, "started", Qt::BlockingQueuedConnection);
 #endif
-
-
 }
 
 void FakeServer::dataAvailable()
@@ -184,7 +182,7 @@ void FakeServer::writeServerPart(int scenarioNumber)
     QTcpSocket *clientSocket = m_clientSockets[scenarioNumber];
 
     while (!scenario.isEmpty()
-            && (scenario.first().startsWith("S: ") || scenario.first().startsWith("W: "))) {
+           && (scenario.first().startsWith("S: ") || scenario.first().startsWith("W: "))) {
         QByteArray rule = scenario.takeFirst();
 
         if (rule.startsWith("S: ")) {
